==> streamix-13.2.1.tar.gz: streamix-13.2.1/streamix/index.py <==
import yt_dlp
import os
from utils import get_ffmpeg_path


# Function to get the Desktop path
def get_desktop_path():
    try:
        desktop_path = os.path.join(os.path.expanduser("~"), "Desktop")
        if not os.path.exists(desktop_path):
            raise Exception("Desktop path not found.")
        return desktop_path
    except Exception as e:
        print(f"Error getting Desktop path: {e}")
        return None


# Function to download video
def download_video(url, quality):
    try:
        # Get Desktop path
        download_path = get_desktop_path()
        if not download_path:
            raise Exception("Unable to resolve Desktop path.")

        ydl_opts = {
            'format': f'bestvideo[height<={quality}]+bestaudio/best',
            'outtmpl': f'{download_path}/%(title)s.%(ext)s',
            'quiet': False,  # Set to True to suppress output logs
            'merge_output_format': 'mp4',
            'geo_bypass': True,
            'http_headers': {
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36'
            },
        }

        # Check if FFmpeg is available
        ffmpeg_path = get_ffmpeg_path()
        if ffmpeg_path:
            ydl_opts['postprocessors'] = [{
                'key': 'FFmpegVideoConvertor',
                'preferedformat': 'mp4',
            }]
        else:
            print("Warning: FFmpeg is not installed. Video and audio may not be merged.")

        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            print(f"Downloading video from {url}...")
            ydl.download([url])
        print(f"Video downloaded successfully to {download_path}!")
    except Exception as e:
        print(f"An error occurred: {e}")


# Function to download audio
def download_audio(url):
    try:
        # Get Desktop path
        download_path = get_desktop_path()
        if not download_path:
            raise Exception("Unable to resolve Desktop path.")

        ydl_opts = {
            'format': 'bestaudio/best',
            'outtmpl': f'{download_path}/%(title)s.%(ext)s',
            'quiet': False,  # Set to True to suppress output logs
            'geo_bypass': True,
            'postprocessors': [{
                'key': 'FFmpegExtractAudio',
                'preferredcodec': 'mp3',
                'preferredquality': '192',
            }] if get_ffmpeg_path() else None
        }

        if not get_ffmpeg_path():
            print("Warning: FFmpeg is not installed. Audio may not be converted to MP3 format.")

        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            print(f"Downloading audio from {url}...")
            ydl.download([url])
        print(f"Audio downloaded successfully to {download_path}!")
    except Exception as e:
        print(f"An error occurred: {e}")


# Main function
def main():
    print("Welcome to Streamix!")
    print("1. Download Video")
    print("2. Download Audio")

    choice = input("Choose an option (1/2): ").strip()

    if choice == '1':
        print("Video Quality Options:")
        print("1. 240p\n2. 360p\n3. 480p\n4. 720p\n5. 1080p")
        quality_map = {'1': '240', '2': '360', '3': '480', '4': '720', '5': '1080'}
        quality = quality_map.get(input("Select quality (1-5): ").strip(), '720')
        url = input("Enter the YouTube URL: ").strip()
        download_video(url, quality)

    elif choice == '2':
        url = input("Enter the YouTube URL: ").strip()
        download_audio(url)
    else:
        print("Invalid option. Exiting.")


# Entry point
if __name__ == "__main__":
    main()

==> streamix-13.2.3.tar.gz: streamix-13.2.3/streamix/index.py <==
import yt_dlp
import os
from .utils import get_ffmpeg_path


# Function to get the Desktop path
def get_desktop_path():
    try:
        # Use `os.path.expanduser` for cross-platform Desktop path
        desktop_path = os.path.join(os.path.expanduser("~"), "Desktop")
        if not os.path.exists(desktop_path):
            raise FileNotFoundError("Desktop path not found.")
        print(f"Resolved Desktop Path: {desktop_path}")  # Debug
        return desktop_path
    except Exception as e:
        print(f"Error getting Desktop path: {e}")
        return None

# Function to download video
def download_video(url, quality):
    try:
        # Get Downloads path
        download_path = get_desktop_path()
        if not download_path:
            raise Exception("Unable to resolve Downloads path.")

        # Prepare yt-dlp options
        ydl_opts = {
            'format': f'bestvideo[height<={quality}]+bestaudio/best',
            'outtmpl': os.path.join(download_path, '%(title)s.%(ext)s'),
            'quiet': False,
            'merge_output_format': 'mp4',
            'geo_bypass': True,
            'http_headers': {
                'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36'
            },
        }

        # Check if FFmpeg is available
        ffmpeg_path = get_ffmpeg_path()
        if ffmpeg_path:
            ydl_opts['postprocessors'] = [{
                'key': 'FFmpegVideoConvertor',
                'preferedformat': 'mp4',
            }]
        else:
            print("Warning: FFmpeg is not installed. Video and audio may not be merged.")

        print(f"Output path template: {ydl_opts['outtmpl']}")  # Debug

        # Download the video
        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            print(f"Downloading video from {url}...")
            ydl.download([url])
        print(f"Video downloaded successfully to {download_path}!")
    except Exception as e:
        print(f"An error occurred during video download: {e}")

# Function to download audio
def download_audio(url):
    try:
        # Get Downloads path
        download_path = get_desktop_path()
        if not download_path:
            raise Exception("Unable to resolve Downloads path.")

        ydl_opts = {
            'format': 'bestaudio/best',
            'outtmpl': os.path.join(download_path, '%(title)s.%(ext)s'),
            'quiet': False,
            'geo_bypass': True,
            'postprocessors': [{
                'key': 'FFmpegExtractAudio',
                'preferredcodec': 'mp3',
                'preferredquality': '192',
            }] if get_ffmpeg_path() else None
        }

        if not get_ffmpeg_path():
            print("Warning: FFmpeg is not installed. Audio may not be converted to MP3 format.")

        print(f"Output path template: {ydl_opts['outtmpl']}")  # Debug

        # Download the audio
        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            print(f"Downloading audio from {url}...")
            ydl.download([url])
        print(f"Audio downloaded successfully to {download_path}!")
    except Exception as e:
        print(f"An error occurred during audio download: {e}")

# Main function
def main():
    print("Welcome to Streamix!")
    print("1. Download Video")
    print("2. Download Audio")

    choice = input("Choose an option (1/2): ").strip()

    if choice == '1':
        print("Video Quality Options:")
        print("1. 240p\n2. 360p\n3. 480p\n4. 720p\n5. 1080p")
        quality_map = {'1': '240', '2': '360', '3': '480', '4': '720', '5': '1080'}
        quality = quality_map.get(input("Select quality (1-5): ").strip(), '720')
        url = input("Enter the YouTube URL: ").strip()
        download_video(url, quality)

    elif choice == '2':
        url = input("Enter the YouTube URL: ").strip()
        download_audio(url)
    else:
        print("Invalid option. Exiting.")


# Entry point
if __name__ == "__main__":
    main()
